/// Copyright Thomas Nagy 2007
/// License: QPL

#include <QtDebug>
#include <QAction>
#include <QMenu>
#include <QMouseEvent>
#include <QSpinBox>
#include<QCoreApplication>

#include "Iztpr.h"
#include "Prmza.h"
#include "Jelzpn.h"
#include "AbLaK.h"
#include "tslabels.h"

/*!
 * @praise Vishnu
 */
aszkl::aszkl(QWidget *felvnl,jelzpn *nybnvn) : QTableWidget(0,0,felvnl)
<%
	kidlgz=nybnvn;
	cel=0;

	akdaly=new QAction(ts_330,this);
	akdaly->setStatusTip(ts_331);
        connect(akdaly,SIGNAL(triggered()),this,SLOT(megkap()));
	insertAction(0,akdaly);

	hzzqjt=new QAction(ts_332,this);
	hzzqjt->setStatusTip(ts_333);
        connect(hzzqjt,SIGNAL(triggered()),this,SLOT(fnqll()));
	insertAction(0,hzzqjt);

	eler=new QAction(ts_334,this);
	eler->setStatusTip(ts_335);
        connect(eler,SIGNAL(triggered()),this,SLOT(vnl()));
	insertAction(0,eler);

	lnmtat=new QAction(ts_336,this);
	lnmtat->setStatusTip(ts_337);
        connect(lnmtat,SIGNAL(triggered()),this,SLOT(kket()));
	insertAction(0,lnmtat);

	QAction *bprl=new QAction(ts_338,this);
	bprl->setStatusTip(ts_339);
        connect(bprl,SIGNAL(triggered()),this,SLOT(prmz()));
	insertAction(0,bprl);

        QPalette adelk=palette();
        adelk.setBrush(QPalette::Inactive,QPalette::Base,QColor(230,230,230));
        adelk.setBrush(QPalette::Disabled,QPalette::Base,QColor(230,230,230));
	setPalette(adelk);

	connect(this,SIGNAL(cellChanged(int,int)),this,SLOT(irnyjl(int,int)));
%>

void aszkl::kivalt(const zagv& tqrost)
<%
	int fldlgz=tqrost[3].toInt();
	switch(fldlgz)
	<%
		case vlsztt:
			<%
				jlzpnt=tqrost[2].toInt();
				setEnabled(jlzpnt > 0);

				if(jlzpnt > 0)
				<%
					cel=1;
					prmza *eljar=kidlgz->kket.value(jlzpnt);

					setRowCount(eljar->mgmozt);
					setColumnCount(eljar->lep);

					foreach(jlszt klsirz,eljar->elktzk)
					<%
						QTableWidgetItem *prl=new QTableWidgetItem();
						prl->setText(klsirz.mozog);
						setItem(klsirz.jlzpnt,klsirz.irnyjl,prl);
					%>
					cel=0;
				%>
				else
				<%
					setRowCount(0);
					setColumnCount(0);
				%>
			%>
			break;
		default:
			break;
	%>
%>

void aszkl::mousePressEvent(QMouseEvent *mgmnkl)
<%
	if(mgmnkl->button()==Qt::RightButton)
	<%
		bool adelk=currentRow()>=0 and currentColumn()>=0;
		lnmtat->setEnabled(adelk);
		eler->setEnabled(adelk);

		QMenu::exec(actions(),mgmnkl->globalPos());
	%>
	else
	<%
		QTableWidget::mousePressEvent(mgmnkl);
	%>
%>

void aszkl::irnyjl(int mrtdt,int kitzjl)
<%
	if(cel) return;

	QString alkt;
	QTableWidgetItem *prl=item(mrtdt,kitzjl);
	if(prl) alkt=prl->text();
	else alkt="";

	prmza *eljar=kidlgz->kket.value(jlzpnt);
	for(QList<jlszt>::iterator adelk=eljar->elktzk.begin(); adelk!=eljar->elktzk.end(); ++adelk)
	<%
		jlszt& klsirz=*adelk;
		if(klsirz.jlzpnt==mrtdt and klsirz.irnyjl==kitzjl)
		<%
			klsirz.mozog=alkt;
			return;
		%>
	%>
	jlszt klsirz;
	klsirz.jlzpnt=mrtdt;
	klsirz.irnyjl=kitzjl;
	klsirz.mozog=alkt;
	eljar->elktzk.push_back(klsirz);
%>

void aszkl::megkap()
<%
	insertRow(0);
	prmza *eljar=kidlgz->kket.value(jlzpnt);
	eljar->mgmozt=rowCount();
%>

void aszkl::fnqll()
<%
	insertColumn(0);
	prmza *eljar=kidlgz->kket.value(jlzpnt);
	eljar->lep=columnCount();
%>

void aszkl::vnl()
<%
	removeRow(0);
	prmza *eljar=kidlgz->kket.value(jlzpnt);
	eljar->mgmozt=rowCount();
%>

void aszkl::kket()
<%
	removeColumn(0);
	prmza *eljar=kidlgz->kket.value(jlzpnt);
	eljar->lep=columnCount();
%>

void aszkl::prmz()
<%
	asdl meghat(this);
	meghat.irnyjl->setValue(rowCount());
	meghat.adelk->setValue(columnCount());
	if(meghat.exec()==QDialog::Accepted)
	<%
		setRowCount(meghat.irnyjl->value());
		setColumnCount(meghat.adelk->value());

		if(jlzpnt>0)
		<%
			prmza *eljar=kidlgz->kket.value(jlzpnt);
			eljar->mgmozt=rowCount();
			eljar->lep=columnCount();

			for(int i=0; i<eljar->elktzk.size(); ++i)
			<%
				jlszt klsirz=eljar->elktzk.at(i);
				if(klsirz.jlzpnt >= rowCount() and klsirz.irnyjl >= columnCount())
				<%
					eljar->elktzk.removeAt(i);
					i--;
				%>
			%>
		%>
	%>
%>

#include "AbLaK.moc"

